==> gnat-1.82-src.tar.gz: gnat-1.82-src/src/ada/a-urealp.h <==
/****************************************************************************/
/*                                                                          */
/*                         GNAT COMPILER COMPONENTS                         */
/*                                                                          */
/*                             A - U R E A L P                              */
/*                                                                          */
/*                              C Header File                               */
/*                                                                          */
/*                            $Revision: 1.1 $                              */
/*                                                                          */
/*           Copyright (c) 1992,1993,1994 NYU, All Rights Reserved          */
/*                                                                          */
/* GNAT is free software;  you can  redistribute it  and/or modify it under */
/* terms of the  GNU General Public License as published  by the Free Soft- */
/* ware  Foundation;  either version 2,  or (at your option) any later ver- */
/* sion.  GNAT is distributed in the hope that it will be useful, but WITH- */
/* OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY */
/* or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License */
/* for  more details.  You should have  received  a copy of the GNU General */
/* Public License  distributed with GNAT;  see file COPYING.  If not, write */
/* to the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
/*                                                                          */
/****************************************************************************/

/* This file corresponds to the Ada package specification Urealp. It was
   created manually from the files urealp.ads and urealp.adb  */

/* Support for universal real arithmetic */

struct Ureal_Entry
{
  Uint Num;
  Uint Den;
  Nat  Bas;
};

extern Uint Denominator  PROTO((Ureal));

extern Uint Numerator    PROTO((Ureal));

extern struct Ureal_Entry *Ureals_Ptr;


#if 0
----------------------
-- REVISION HISTORY --
----------------------

----------------------------
revision 1.1
date: Thu Jun  2 16:01:28 1994;  author: crozes
Initial revision
----------------------------
** New changes after this line and before endif. **
#endif

==> gnat-2.04-src.tar.gz: gnat-2.04-src/src/ada/a-urealp.h <==
/****************************************************************************/
/*                                                                          */
/*                         GNAT COMPILER COMPONENTS                         */
/*                                                                          */
/*                             A - U R E A L P                              */
/*                                                                          */
/*                              C Header File                               */
/*                                                                          */
/*                            $Revision: 1.3 $                              */
/*                                                                          */
/*           Copyright (c) 1992,1993,1994 NYU, All Rights Reserved          */
/*                                                                          */
/* GNAT is free software;  you can  redistribute it  and/or modify it under */
/* terms of the  GNU General Public License as published  by the Free Soft- */
/* ware  Foundation;  either version 2,  or (at your option) any later ver- */
/* sion.  GNAT is distributed in the hope that it will be useful, but WITH- */
/* OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY */
/* or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License */
/* for  more details.  You should have  received  a copy of the GNU General */
/* Public License  distributed with GNAT;  see file COPYING.  If not, write */
/* to the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
/*                                                                          */
/****************************************************************************/

/* This file corresponds to the Ada package specification Urealp. It was
   created manually from the files urealp.ads and urealp.adb  */

/* Support for universal real arithmetic */

struct Ureal_Entry
{
  Uint    Num;
  Uint    Den;
  Nat     Bas;
  Boolean Negative;
};

extern Uint Denominator  PROTO((Ureal));

extern Uint Numerator    PROTO((Ureal));

#define Ureals_Ptr (urealp__ureals__table - Ureal_First_Entry)
extern struct Ureal_Entry *urealp__ureals__table;
